# jaguar_mongo

A MongoDB interceptor for Jaguar. 

# Usage

## Creating the pool

Create an instance of `MongoPool`. Supply essential database configuration. By default,
`MongoPool` builds on a `SharedPool`. Supply `minPoolSize` and `maxPoolSize` to control the
pool size.

```dart
final mongoPool = MongoPool('mongodb://localhost:27017/test');
```

## Declaring the interceptor

`PostgresPool` exposes `injectInterceptor` method to interceptor a route and add `PostgreSQLConnection`
instance to it.

```dart
Future<void> mongoInterceptor(Context ctx) => mongoPool.injectInterceptor(ctx);
```

## Intercepting routes

Add the `mongoInterceptor` interceptor to the route chain.

```dart
@Controller(path: '/contact')
@Intercept(const [mongoInterceptor])
class ContactApi {
  // TODO Add routes ...
}
```

## Getting and using connection

In the route handler, get `Db` using `getVariable<Db>` method of route `Context`.

```dart
  @GetJson()
  Future<List> readAll(Context ctx) async {
     Db db = ctx.getVariable<Db>(); // Get [Db]
    // Use Db to fetch items
    return await (await db.collection('contact').find()).toList();
  }
```